/******************************************************************************
* C Include: Extraction                                                       *
*                                                                             *
* File:                                                                       *
*    extrctn.h                                                                *
*                                                                             *
* Description:                                                                *
*    Include file for the Extraction Data structure                           *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#ifndef __EXTRCTN__
#define __EXTRCTN__

#include <stdio.h>

#include "field.h"
#include "fieldlst.h"
#include "hdrlist.h"
#include "imgsectn.h"
#include "imgsnlst.h"
#include "plate.h"
#include "platelst.h"

/********************************
* Extraction derived data types *
********************************/
struct Extraction_Info
{
   FIELD         Field        ;
   PLATE         Plate        ;
   IMAGE_SECTION Image_Section;
};
typedef struct Extraction_Info * EXTRACTION;

/***********************************
* Extraction functions' prototypes *
***********************************/
int        Compare_Extractions (/* EXTRACTION    Extraction_1 ,
				   EXTRACTION    Extraction_2  */);

void       Delete_Extraction   (/* EXTRACTION    Extraction    */);

EXTRACTION Get_Extraction      (/* FIELD         Field        ,
				   PLATE         Plate        ,
				   IMAGE_SECTION Image_Section */);








/*********************************
* Extraction include file page 2 *
*********************************/

EXTRACTION Read_Extraction_Info(/* FILE       *Input_File        ,
				   PLATE_LIST  Plate_List        ,
				   STRING      Header_Directory  ,
				   STRING      Header_Extension  ,
				   FIELD_LIST  Field_List        ,
				   IS_LIST     Image_Section_List,
				   HDR_LIST    Header_List        */);

void         Write_Extraction_Information
                                        (/* EXTRACTION  Extraction        ,
					    FILE       *File               */);

#endif
